未麻的部屋 (豆瓣)
Description: 未麻的部屋电影简介和剧情介绍,未麻的部屋影评、图片、预告片、影讯、论坛、在线购票
Keywords: 未麻的部屋,Perfect Blue,未麻的部屋影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.135豆瓣电影Top250

# 未麻的部屋 Perfect Blue (1997)

导演: 今敏
编剧: 村井贞之 / 竹内义和
主演: 岩男润子 / 松本梨香 / 辻亲八 / 大仓正章 / 秋元羊介 / 盐屋翼 / 堀秀行 / 筱原惠美 / 江原正士 / 梁田清之 / 古泽彻 / 新山志保 / 古川惠实子 / 原亚弥 / 三木真一郎 / 山野井仁 / 田野惠 / 长嶝高士 / 陶山章央 / 细井治 / 远近孝一 / 本井英美 / 保志总一朗 / 谷山纪章 / 北野诚 / 南香织 / 商店一野
类型: 动画 / 惊悚 / 奇幻
制片国家/地区: 日本
语言: 日语
上映日期: 1997-08-05(加拿大奇幻电影节) / 1998-02-28(日本)
片长: 81 分钟
又名: 蓝色恐惧(港/台) / 蓝色的恐惧 / 未麻之部屋 / パーフェクト ブルー
IMDb: tt0156887
豆瓣评分
引用
9.1
306545人评价
5星
60.9%
4星
32.0%
3星
6.4%
2星
0.5%
1星
0.2%
好于 98% 动画片
好于 99% 惊悚片
想看 看过
评价:
推荐

## 未麻的部屋的剧情简介 · · · · · ·

当红三人少女偶像团体Charming Bird面临解散，核心成员雾越未麻在事务所的安排下不得不退出团体，转型成为一名电视剧演员。万事开头难，对于偶像歌手转型而来的未麻尤其如此，她在工作中承受着压力，闷闷不乐。与此同时，各种恐吓信不断、经纪人田所先生遇袭以及以自己的口吻在网站上写日记的神秘人都让未麻焦虑不已，恍惚间她甚至看到另一个自己。
未麻的苦恼无人知晓，贪婪的田所甚至同意剧组的剧本，要求未麻出演一场尺度极大的强暴戏。这次演出成为未麻演艺事业的转折点，她的出镜率开始攀升，甚至还拍摄了裸露的写真。与此相对，电视剧编剧涩谷和曾给未麻拍下裸照摄影师村野接连遇害。未麻的生活变得混乱不堪，真相究竟如何？
本片荣获1997年亚洲奇幻电影节最佳亚洲影片。 ©豆瓣

## 未麻的部屋的演职员 · · · · · · ( 全部 30 )

- 今敏 导演
- 岩男润子 配 雾越未麻
- 松本梨香 配 留美
- 辻亲八 配 田所
- 大仓正章 配音
- 秋元羊介 配 手岛

## 未麻的部屋的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片759 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  红辣椒

  千年女优

  东京教父

  幽灵公主

  天空之城

  大闹天宫

  风之谷

  回忆三部曲

  心理游戏

  哪吒闹海

我要写短评

## 未麻的部屋的短评 · · · · · · ( 全部 81469 条 )

热门 / 最新 / 好友

### 4738 有用 托尼·王大拿 看过 2011-04-24 14:15:26

达伦，你到底从今敏那里偷了多少灵感，这和《黑天鹅》的设定有很多相似之处啊！镜子的割裂，心理暗示，散碎的剪辑，真他妈牛逼。

### 3458 有用 易老邪 看过 2010-11-02 23:06:44

片子结尾将一切坐实为留美所为不能不说有丝遗憾，其实我个人更赞赏影片60多分钟时的那个剧情构思和说法，即，之前所发生的一切只是一个名叫高仓阳子的平凡女子的人格分裂，把自己幻想为偶像歌女雾越未麻，把自己不堪回首的遭遇幻想成在演戏，藉此得以解脱。

### 2151 有用 老阿飞—故园 看过 2006-03-15 03:35:48

谁说今敏不牛b我跟谁急

### 3287 有用 如花就是小妖 看过 2009-12-15 13:50:33

好的剧本就是就算你猜到了结局也猜不到全部

### 2732 有用 翻滚吧！蛋堡 看过 2015-07-08 00:13:12

看今敏解读，他自己提到《梦之安魂曲》里浴室镜头的模仿：“什么致敬，明明就是抄袭！那个坐在浴缸里的女主角就是詹妮弗·康纳利。后来我还和她坐过同一架飞机，结果她在头等舱，我在经济舱。”哈哈哈哈哈哈

> 更多短评 81469条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 未麻的部屋的影评 · · · · · · ( 全部 798 条 )

热门 / 最新 / 好友
zzfznp 2011-12-18 18:35:55

## 个人观点详细解构《未麻的部屋》每一个环节

ME MANIA也就是这个长相猥琐的未麻歌迷是负责现场保卫工作的，同时也是未麻的fans（制止少年骚扰后回到原位，旁边有一位跟他穿同样衣服的保安）。 未麻回到家后母亲打电话来，中间插入一个电话，没有声音。这个电话可能是留美打的，对于明星来说，她住处的电话不太可能被其他路... (展开)
3575 175 328回应 收起
谢谢 2014-06-08 21:28:58

## 《未麻的部屋》全面解析——只为逃离现实而做的黄粱美梦

这篇影评可能有剧透

首先得感谢已故的金敏导演，这是一部非常棒的电影。第一次遇到让我看完以后如此兴奋不已的动画，在此之前，只有《穆赫兰道》让我有过同样按耐不住想写点什么与大家分享的冲动。 我们都不是导演或是编剧，没办法解释每一个镜头分别有什么内涵。但是我们可以通过各个镜头留给我们... (展开)
3020 72 320回应 收起
有门手艺叫沙雕 2009-03-28 01:13:16

## 有点流水帐，但我觉得我深入地看懂了90%

这篇影评可能有剧透

warning !: 现在再看自己几年前写的东西,只觉得当年功力不足而有很多地方过度解析,导致非常偏颇.现在看起来确实是很蠢.但非常感谢大家一直以来的回复. 我想说的是，这部片或者还有另一个解释。 或者是经过大卫林奇的洗礼，我觉得我好像看懂了这部片。原来，大卫林奇并不是第一... (展开)
2175 442 261回应 收起
江枫渔火 2015-12-07 22:28:21

## 《Perfect Blue》今敏讲座完整版摘要

这篇影评可能有剧透

现在网上广为流传的是40分钟的版本，实际上这个视频完整版为110分钟。目前没有哪个字幕组把他翻译完全。于是我请教了一位日语大神的好友，一起来把这个完整版的视频重译一下。由于这类访谈拉片的形式翻译起来难度较大（今敏说话还文绉绉的好讨厌），我就让小伙伴先过一遍把主要... (展开)
730 5 44回应 收起
daculax 2008-03-31 20:19:50

## 值得看多几遍的好片~~

故事前半段看似波澜不惊，似乎仅仅是一个变态歌迷威胁偶像的老套故事，偶像歌手未麻和新人演员未麻作为未麻内心得两个对立面的出现，试图通过描述未麻在压力下产生的幻觉将观众引入“未麻精神分裂”的歧途， 故事的主线人物看似只有未麻和疯狂迷恋歌手未麻的歌迷ME-Mania，未... (展开)
644 41 113回应 收起
Joseph 2019-06-24 02:14:46 #《未麻的部屋》有哪些高明的细节？

## 《未麻的部屋》有哪些高明的细节？——日历即是totem

这篇影评可能有剧透

豆瓣大神们的评论已经分析了很多了。我就再补充一点。 借用《盗梦空间》的totem概念，totem是用以区分现实和梦境的工具。那么，在《未麻的部屋》里，区分现实和梦境（或者幻觉）的totem，就是未麻房间（以及最后留美房间）里的日历。 以此为基准，我们可以做出一份正确的日历，... (展开)
301 32回应 收起
陈永仁 2008-02-23 17:37:19

## 超越时代(不止)十年的作品

2008年3月1日至3月12日，一个名为《十年的土产》免费展览会在日本新宿的眼科画廊举办，举办的意义是为了纪念十年前的一部动画《Perfect Blue》，举办人正是本片导演——今敏。 20世纪90年代初的日本动画，虽有押井守的《机动警察2：东京保卫战》这样的深刻作品，但由于吉普力... (展开)
319 72 65回应 收起
克劳克罗 2006-10-29 22:55:35

## 论如何模糊现实与幻想的边界，以及如何误导读者的期望

这篇影评可能有剧透

刚刚看完这部向往已久的作品，各种感性评价就不说了，网上评论有得是，俺倒是想以一个同人写手的眼光，来谈谈这部片子里面用的各种技巧。 今敏是靠大师级的现实与虚幻的交替手法起家的，而且至今仍在靠这个吃饭。《妄想代理人》里呈现出的还是他的老一套，这个且略去不表，单... (展开)
254 51 53回应 收起
思念 2018-12-18 17:32:37 #《未麻的部屋》有哪些精彩的细节？

## 看过的人多数没追过星，正追星的人多数没看过

这篇影评可能有剧透

问：那个许多人都看不懂的“一分钟”，究竟是什么含义？ 答：要理解这“一分钟”的含义，首先需要明白电视剧拍摄的流程。以雾越未麻第一次进片场时为例。首先，落合惠利和男演员把剧情演一遍，导演喊“好！结束”；然后，导演回看刚才的拍摄过程，满意之后喊“好！OK！”，这样... (展开)
196 4 12回应 收起
听霜书生 2011-01-11 00:25:01

## 是不是电影让你昏了？

我这个题目，大家不要以为是说这个电影本身，我想说的是那些写评论的。很多人的评论里总有一种今敏这篇作品在借鉴别人的论调。 hugebaby 童鞋的评论里面有这么一段话： “不过此类电影他并非首创先河，只不过他是用动画语言呈现这一理念的先行者。《搏击会》（Fight club）... (展开)
157 6 10回应 收起

> 更多影评 798篇

添加新讨论

## 讨论区 · · · · · ·

为什么英文名叫perfect blue | 来自下沉岁月 | 1 回应 | 2022-11-24 18:31:04
一部要听你们解释才能看懂的电影值9分？ | 来自看看星星，数数 | 19 回应 | 2022-11-23 14:48:53
未麻被强奸那段实在是太虐了 | 来自小北 | 120 回应 | 2022-11-23 02:12:35
留美画的那么丑，应该想到是她的 | 来自momo |  | 2022-11-21 22:08:31
对宫崎骏的作品无感，却对今敏的作品很是喜欢 | 来自黑旋 | 2 回应 | 2022-11-12 23:12:21

> 去这部影片的讨论区（全部190条）

## 关于《未麻的部屋》的问题 · · · · · · ( 全部39个 )

- 最後老闆為什麼會和狂人死在一起？ 5人回答
- 日本实力派女演员需要拍全裸写真吗？ 8人回答

> 全部39个问题

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 【大爱の日剧♂电影♀动画全收录】 (狷介有乌青)
- 桃桃推荐｜值得一看（209部） (桃桃林林)
- 日本动画推荐 (恶魔的步调)
- 私人五星，有的看过第二遍，还要看第三四遍 (水木丁)

## 谁在看这部电影 · · · · · ·

- Lose.
  1分钟前 看过
- 解语花
  6分钟前 看过
- 八声甘州
  7分钟前 看过

386241人看过 / 273707人想看

订阅未麻的部屋的评论:
feed: rss 2.0